{ inputs, pkgs, ... }:

{
  # Basic user info
  home.username = "crony";
  home.homeDirectory = "/home/crony";

  # DO NOT CHANGE
  home.stateVersion = "23.11";

  # Imports
  imports = [
    ./modules/gpg.nix
    ./modules/btop.nix
    ./modules/mpv.nix
    ./modules/tmux.nix
    ./modules/nnn.nix
    ./modules/dmenu.nix
    ./modules/mangohud.nix
    ./modules/shell.nix
    ./modules/nvim.nix
    ./modules/restic.nix
    #    ./modules/theming.nix Not needed when using plasma
    ./modules/plasma.nix
    ./modules/alacritty.nix
    ./modules/newsboat.nix
    ./modules/helix.nix
    ./modules/tofi.nix
    ./modules/vkbasalt.nix
  ];

  # My packages
  home.packages = with pkgs; [
    librewolf # Nice privacy browser
    thunderbird # Nice mail client
    qutebrowser # Nice browser in general
    armcord # Nicer discord client
    keepassxc # Best password manager
    buku # Nice bookmark manager
    bukubrow # Nice bookmark manager browser support
    rclone # Best sync client in the world
    age # Simple file encryption
    nitch # Simple system info
    neofetch # Neo
    libarchive # bsdtar
    imagemagick # image tools
    ffmpeg # video manupilation
    glow # markdown viewer
    piper # ratbagd mice config gui
    krita # best drawing program
    tutanota-desktop # fjdlkfjldjflkd
    delfin # jellyfin client
    nurl # nix git config tool
    ripgrep # Neovim telescope dependency
    lazygit # Amazing git tui
    lm_sensors # Sensor monitoring tool
    feather # Amazing monero wallet
    heroic # Epic games/gog game launcher
    protonvpn-gui # Proton vpn gui app
    beets # Music tagger
    nicotine-plus # Amazing soulseek client
    prismlauncher # Best minecraft launcher
    aria2 # Fast download manager
    starsector # Nice little game I got coaxed into trying
    inputs.hb-downloader.packages.${pkgs.system}.default # My custom humble bundle bulk link extractor for aria2 list format
    hugo # fast static site generator
    protonup-qt # Proton ge manager
    ungoogled-chromium # For sites that don't work with firefox based browsers
    (nerdfonts.override { fonts = [ "CascadiaCode" ]; }) # Best font
    (retroarch.override { cores = with libretro; [ snes9x ]; })
  ];

  # Environmental variables I can't live without
  home.sessionVariables = {
    EDITOR = "nvim";
    BROWSER = "qutebrowser";
    TERMINAL = "alacritty";
  };

  # Fix environmental variables not loaded in plasma x11
  xsession.enable = true;

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  # Home manager settings
  dconf.settings = {
    "org/virt-manager/virt-manager/connections" = {
      autoconnect = [ "qemu:///system" ];
      uris = [ "qemu:///system" ];
    };
  };
}
